slepc-3.18.0 2022-10-01
Report Typos and Errors

# VecNormalizeComplex

Normalizes a possibly complex vector by the 2-norm.

### Synopsis

    #include "slepcvec.h"
    PetscErrorCode VecNormalizeComplex(Vec xr,Vec xi,PetscBool iscomplex,PetscReal *norm)

Collective on xr

### Input Parameters

| xr | - the real part of the vector (overwritten on output)
| xi | - the imaginary part of the vector (not referenced if iscomplex is false)
| iscomplex | - a flag indicating if the vector is complex

### Output Parameter

| norm | - the vector norm before normalization (can be set to NULL)

### See Also

BVNormalize()

### Level

developer

### Location

src/sys/vec/vecutil.c
Index of all sys routines
Table of Contents for all manual pages
Index of all manual pages